==> fp-ts-indexed-monad-2.10.1.tgz: package/es6/IxState.js <==
/**
 * `IxState` (Indexed State) is a derivation of `State`, that may have **polymorphic** states;
 * The input may be of a different type than the output.
 *
 * State changes are kept track of by the generics `I`, `O`, `X` and `Z`.
 * - `I` indicates the current input state
 * - `O` indicates the current output state
 * - `Z` indicates the next input state
 * - `Z` indicates the next output state
 *
 * When composing `IxState` where the indexes are polymorhpic, functions `ixchain` and `ixap` can be
 * used to compose `<I, O>` with `<O, Z>` to return `<I, Z>`.
 *
 * Intuitively this is function composition on the indexes.
 *
 *
 * `IxState` derived by applying the `Identity` monad to the transformer `IxStateT`.
 * @since 2.10.0
 */
import { apFirst as apFirst_, apS as apS_, apSecond as apSecond_ } from 'fp-ts/Apply';
import { bind as bind_, chainFirst as chainFirst_ } from 'fp-ts/Chain';
import { bindTo as bindTo_, flap as flap_ } from 'fp-ts/Functor';
import * as I from 'fp-ts/Identity';
import { ixapFirst as ixapFirst_, ixapS as ixapS_, ixapSecond as ixapSecond_ } from './IxApply';
import { ixbind as ixbind_, ixchainFirst as ixchainFirst_, ixDo as ixDo_ } from './IxChain';
import { ixbindTo as ixbindTo_, ixflap as ixflap_ } from './IxFunctor';
import * as IxStateT from './IxStateT';
/**
 * @category Model
 * @since 2.10.0
 */
export var URI = 'IxState';
// -------------------------------------------------------------------------------------
// constructors
// -------------------------------------------------------------------------------------
/**
 * @summary
 * Apply a function to the state, polymorphically changing the resulting state.
 *
 * @category constructors
 * @since 2.10.0
 */
export var ixmodify = 
/*#__PURE__*/
IxStateT.ixmodify(I.Pointed);
/**
 * @category constructors
 * @since 2.10.0
 */
export var put = 
/*#__PURE__*/
IxStateT.put(I.Pointed);
/**
 * @category constructors
 * @since 2.10.0
 */
export var fromState = IxStateT.fromStateF();
/**
 * @category constructors
 * @since 2.10.0
 */
export var get = 
/*#__PURE__*/
IxStateT.get(I.Pointed);
/**
 * @category constructors
 * @since 2.10.0
 */
export var gets = 
/*#__PURE__*/
IxStateT.gets(I.Pointed);
// -------------------------------------------------------------------------------------
// destructors
// -------------------------------------------------------------------------------------
/**
 * @category destructors
 * @since 2.10.0
 */
export var toState = IxStateT.toStateF();
/**
 * @category destructors
 * @since 2.10.0
 */
export var ixexecute = 
/*#__PURE__*/
IxStateT.ixexecute(I.Functor);
/**
 * @category destructors
 * @since 2.10.0
 */
export var evaluate = 
/*#__PURE__*/
IxStateT.evaluate(I.Functor);
// -------------------------------------------------------------------------------------
// non-pipeables
// -------------------------------------------------------------------------------------
var _ixof = function (a) { return function (i) { return [a, i]; }; };
var _ixmap = function (fa, f) { return function (i) {
    var _a = fa(i), a = _a[0], o = _a[1];
    return [f(a), o];
}; };
var _ixap = function (fab, fa) { return function (i) {
    var _a = fab(i), f = _a[0], o = _a[1];
    var _b = fa(o), a = _b[0], z = _b[1];
    return [f(a), z];
}; };
var _ixchain = function (fa, f) { return function (i) {
    var _a = fa(i), a = _a[0], o = _a[1];
    var _b = f(a)(o), b = _b[0], z = _b[1];
    return [b, z];
}; };
var _of = _ixof;
var _map = _ixmap;
var _ap = _ixap;
var _chain = _ixchain;
// -------------------------------------------------------------------------------------
// instances
// -------------------------------------------------------------------------------------
/**
 * @category instances
 * @since 2.10.0
 */
export var IxFunctor = {
    URI: URI,
    ixmap: function (f) { return function (fa) { return _ixmap(fa, f); }; },
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxApply = {
    URI: URI,
    ixmap: IxFunctor.ixmap,
    ixap: function (fa) { return function (fab) { return _ixap(fab, fa); }; },
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxChain = {
    URI: URI,
    ixmap: IxFunctor.ixmap,
    ixap: IxApply.ixap,
    ixchain: function (f) { return function (fa) { return _ixchain(fa, f); }; },
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxPointed = {
    URI: URI,
    ixof: _ixof,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxApplicative = {
    URI: URI,
    ixof: IxPointed.ixof,
    ixmap: IxFunctor.ixmap,
    ixap: IxApply.ixap,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxMonad = {
    URI: URI,
    ixof: IxPointed.ixof,
    ixmap: IxFunctor.ixmap,
    ixap: IxApply.ixap,
    ixchain: IxChain.ixchain,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Pointed = { URI: URI, of: _of };
/**
 * @category instances
 * @since 2.10.0
 */
export var Functor = {
    URI: URI,
    map: _ixmap,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Apply = {
    URI: URI,
    map: _map,
    ap: _ap,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Chain = {
    URI: URI,
    map: _map,
    ap: _ap,
    chain: _chain,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Monad = {
    URI: URI,
    of: _of,
    map: _map,
    ap: _ap,
    chain: _chain,
};
// -------------------------------------------------------------------------------------
// type class members
// -------------------------------------------------------------------------------------
/**
 * @category IxPointed
 * @since 2.10.0
 */
export var ixof = _ixof;
/**
 * @category IxFunctor
 * @since 2.10.0
 */
export var ixmap = 
/*#__PURE__*/
IxStateT.ixmap(I.Functor);
/**
 * @category IxFunctor
 * @since 2.10.0
 */
export var ixflap = 
/*#__PURE__*/
ixflap_(IxFunctor);
/**
 * Apply a function to an argument under a type constructor.
 *
 * @category IxApply
 * @since 2.10.0
 */
export var ixap = 
/*#__PURE__*/
IxStateT.ixap(I.Chain);
/**
 * @category IxApply
 *
 * @since 2.10.0
 */
export var ixapFirst = 
/*#__PURE__*/
ixapFirst_(IxApply);
/**
 * @category IxApply
 * @since 2.10.0
 */
export var ixapSecond = 
/*#__PURE__*/
ixapSecond_(IxApply);
/**
 * @category Apply
 *
 * @since 2.10.0
 */
export var apFirst = 
/*#__PURE__*/
apFirst_(Apply);
/**
 * @category Apply
 * @since 2.10.0
 */
export var apSecond = 
/*#__PURE__*/
apSecond_(Apply);
/**
 * Composes computations in sequence, using the return value of one computation to determine the next computation.
 *
 * @category IxChain
 *
 * @since 2.10.0
 */
export var ixchain = 
/*#__PURE__*/
IxStateT.ixchain(I.Chain);
/**
 * @category IxChain
 * @since 2.10.0
 */
export var ixchainFirst = 
/*#__PURE__*/
ixchainFirst_(IxChain);
/**
 * @category Chain
 * @since 2.10.0
 */
export var chainFirst = 
/*#__PURE__*/
chainFirst_(Chain);
/**
 * @category Pointed
 * @since 2.10.0
 */
export var of = 
/*#__PURE__*/
IxStateT.of(I.Pointed);
/**
 * `map` can be used to turn functions `(a: A) => B` into functions `(fa: F<A>) => F<B>` whose argument and return types
 * use the type constructor `F` to represent some computational context.
 *
 * @category Functor
 * @since 2.10.0
 */
export var map = 
/*#__PURE__*/
IxStateT.map(I.Functor);
/**
 * `map` can be used to turn functions `(a: A) => B` into functions `(fa: F<A>) => F<B>` whose argument and return types
 * use the type constructor `F` to represent some computational context.
 *
 * @category Functor
 * @since 2.10.0
 */
export var flap = 
/*#__PURE__*/
flap_(Functor);
/**
 *
 * @category Apply
 * @since 2.10.0
 */
export var ap = 
/*#__PURE__*/
IxStateT.ap(I.Chain);
/**
 *
 * @category Chain
 * @since 2.10.0
 */
export var chain = 
/*#__PURE__*/
IxStateT.chain(I.Chain);
// -------------------------------------------------------------------------------------
// combinators
// -------------------------------------------------------------------------------------
/**
 * Changes the value of the local context during the execution of the action `ma` (similar to `Contravariant`'s
 * `contramap`).
 *
 * @category combinators
 * @since 2.10.0
 */
export var local = IxStateT.local();
// -------------------------------------------------------------------------------------
// do notation
// -------------------------------------------------------------------------------------
/**
 * @since 2.10.0
 */
export var ixDo = 
/*#__PURE__*/
ixDo_(Pointed);
/**
 * @since 2.10.0
 */
export var Do = ixDo;
/**
 * @since 2.10.0
 */
export var ixbind = 
/*#__PURE__*/
ixbind_(IxChain);
/**
 * @since 2.10.0
 */
export var ixbindTo = 
/*#__PURE__*/
ixbindTo_(IxChain);
/**
 * @since 2.10.0
 */
export var bind = 
/*#__PURE__*/
bind_(Chain);
/**
 * @since 2.10.0
 */
export var bindTo = 
/*#__PURE__*/
bindTo_(Chain);
/**
 * ixDo-notation combinator for discarding the result of a computation rather
 * than binding it to a name. It is simply an alias for `ixchainFirst`
 * @since 2.10.0
 */
export var ixdiscard = ixchainFirst;
/**
 * Do-notation combinator for discarding the result of a computation rather
 * than binding it to a name. It is simply an alias for `chainFirst`
 * @since 2.10.0
 */
export var discard = chainFirst;
// -------------------------------------------------------------------------------------
// pipeable sequence S
// -------------------------------------------------------------------------------------
/**
 * @since 2.10.0
 */
export var ixapS = 
/*#__PURE__*/
ixapS_(IxApply);
/**
 * @since 2.10.0
 */
export var apS = 
/*#__PURE__*/
apS_(Apply);

==> fp-ts-indexed-monad-2.10.2.tgz: package/es6/IxState.js <==
/**
 * `IxState` (Indexed State) is a derivation of `State`, that may have **polymorphic** states;
 * The input may be of a different type than the output.
 *
 * State changes are kept track of by the generics `I`, `O`, `X` and `Z`.
 * - `I` indicates the current input state
 * - `O` indicates the current output state
 * - `Z` indicates the next input state
 * - `Z` indicates the next output state
 *
 * When composing `IxState` where the indexes are polymorhpic, functions `ixchain` and `ixap` can be
 * used to compose `<I, O>` with `<O, Z>` to return `<I, Z>`.
 *
 * Intuitively this is function composition on the indexes.
 *
 *
 * `IxState` derived by applying the `Identity` monad to the transformer `IxStateT`.
 * @since 2.10.0
 */
import { apFirst as apFirst_, apS as apS_, apSecond as apSecond_ } from 'fp-ts/Apply';
import { bind as bind_, chainFirst as chainFirst_ } from 'fp-ts/Chain';
import { bindTo as bindTo_, flap as flap_ } from 'fp-ts/Functor';
import * as I from 'fp-ts/Identity';
import { ixapFirst as ixapFirst_, ixapS as ixapS_, ixapSecond as ixapSecond_ } from './IxApply';
import { ixbind as ixbind_, ixchainFirst as ixchainFirst_, ixDo as ixDo_ } from './IxChain';
import { ixbindTo as ixbindTo_, ixflap as ixflap_, ixlet as ixlet_ } from './IxFunctor';
import * as IxStateT from './IxStateT';
/**
 * @category Model
 * @since 2.10.0
 */
export var URI = 'IxState';
// -------------------------------------------------------------------------------------
// constructors
// -------------------------------------------------------------------------------------
/**
 * @summary
 * Apply a function to the state, polymorphically changing the resulting state.
 *
 * @category constructors
 * @since 2.10.0
 */
export var ixmodify = 
/*#__PURE__*/
IxStateT.ixmodify(I.Pointed);
/**
 * @category constructors
 * @since 2.10.0
 */
export var put = 
/*#__PURE__*/
IxStateT.put(I.Pointed);
/**
 * @category constructors
 * @since 2.10.0
 */
export var fromState = IxStateT.fromStateF();
/**
 * @category constructors
 * @since 2.10.0
 */
export var get = 
/*#__PURE__*/
IxStateT.get(I.Pointed);
/**
 * @category constructors
 * @since 2.10.0
 */
export var gets = 
/*#__PURE__*/
IxStateT.gets(I.Pointed);
// -------------------------------------------------------------------------------------
// destructors
// -------------------------------------------------------------------------------------
/**
 * @category destructors
 * @since 2.10.0
 */
export var toState = IxStateT.toStateF();
/**
 * @category destructors
 * @since 2.10.0
 */
export var ixexecute = 
/*#__PURE__*/
IxStateT.ixexecute(I.Functor);
/**
 * @category destructors
 * @since 2.10.0
 */
export var evaluate = 
/*#__PURE__*/
IxStateT.evaluate(I.Functor);
// -------------------------------------------------------------------------------------
// non-pipeables
// -------------------------------------------------------------------------------------
var _ixof = function (a) { return function (i) { return [a, i]; }; };
var _ixmap = function (fa, f) { return function (i) {
    var _a = fa(i), a = _a[0], o = _a[1];
    return [f(a), o];
}; };
var _ixap = function (fab, fa) { return function (i) {
    var _a = fab(i), f = _a[0], o = _a[1];
    var _b = fa(o), a = _b[0], z = _b[1];
    return [f(a), z];
}; };
var _ixchain = function (fa, f) { return function (i) {
    var _a = fa(i), a = _a[0], o = _a[1];
    var _b = f(a)(o), b = _b[0], z = _b[1];
    return [b, z];
}; };
var _of = _ixof;
var _map = _ixmap;
var _ap = _ixap;
var _chain = _ixchain;
// -------------------------------------------------------------------------------------
// instances
// -------------------------------------------------------------------------------------
/**
 * @category instances
 * @since 2.10.0
 */
export var IxFunctor = {
    URI: URI,
    ixmap: function (f) { return function (fa) { return _ixmap(fa, f); }; },
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxApply = {
    URI: URI,
    ixmap: IxFunctor.ixmap,
    ixap: function (fa) { return function (fab) { return _ixap(fab, fa); }; },
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxChain = {
    URI: URI,
    ixmap: IxFunctor.ixmap,
    ixap: IxApply.ixap,
    ixchain: function (f) { return function (fa) { return _ixchain(fa, f); }; },
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxPointed = {
    URI: URI,
    ixof: _ixof,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxApplicative = {
    URI: URI,
    ixof: IxPointed.ixof,
    ixmap: IxFunctor.ixmap,
    ixap: IxApply.ixap,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var IxMonad = {
    URI: URI,
    ixof: IxPointed.ixof,
    ixmap: IxFunctor.ixmap,
    ixap: IxApply.ixap,
    ixchain: IxChain.ixchain,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Pointed = { URI: URI, of: _of };
/**
 * @category instances
 * @since 2.10.0
 */
export var Functor = {
    URI: URI,
    map: _ixmap,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Apply = {
    URI: URI,
    map: _map,
    ap: _ap,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Chain = {
    URI: URI,
    map: _map,
    ap: _ap,
    chain: _chain,
};
/**
 * @category instances
 * @since 2.10.0
 */
export var Monad = {
    URI: URI,
    of: _of,
    map: _map,
    ap: _ap,
    chain: _chain,
};
// -------------------------------------------------------------------------------------
// type class members
// -------------------------------------------------------------------------------------
/**
 * @category IxPointed
 * @since 2.10.0
 */
export var ixof = _ixof;
/**
 * @category IxFunctor
 * @since 2.10.0
 */
export var ixmap = 
/*#__PURE__*/
IxStateT.ixmap(I.Functor);
/**
 * @category IxFunctor
 * @since 2.10.0
 */
export var ixflap = 
/*#__PURE__*/
ixflap_(IxFunctor);
/**
 * Apply a function to an argument under a type constructor.
 *
 * @category IxApply
 * @since 2.10.0
 */
export var ixap = 
/*#__PURE__*/
IxStateT.ixap(I.Chain);
/**
 * @category IxApply
 *
 * @since 2.10.0
 */
export var ixapFirst = 
/*#__PURE__*/
ixapFirst_(IxApply);
/**
 * @category IxApply
 * @since 2.10.0
 */
export var ixapSecond = 
/*#__PURE__*/
ixapSecond_(IxApply);
/**
 * @category Apply
 *
 * @since 2.10.0
 */
export var apFirst = 
/*#__PURE__*/
apFirst_(Apply);
/**
 * @category Apply
 * @since 2.10.0
 */
export var apSecond = 
/*#__PURE__*/
apSecond_(Apply);
/**
 * Composes computations in sequence, using the return value of one computation to determine the next computation.
 *
 * @category IxChain
 *
 * @since 2.10.0
 */
export var ixchain = 
/*#__PURE__*/
IxStateT.ixchain(I.Chain);
/**
 * @category IxChain
 * @since 2.10.0
 */
export var ixchainFirst = 
/*#__PURE__*/
ixchainFirst_(IxChain);
/**
 * @category Chain
 * @since 2.10.0
 */
export var chainFirst = 
/*#__PURE__*/
chainFirst_(Chain);
/**
 * @category Pointed
 * @since 2.10.0
 */
export var of = 
/*#__PURE__*/
IxStateT.of(I.Pointed);
/**
 * `map` can be used to turn functions `(a: A) => B` into functions `(fa: F<A>) => F<B>` whose argument and return types
 * use the type constructor `F` to represent some computational context.
 *
 * @category Functor
 * @since 2.10.0
 */
export var map = 
/*#__PURE__*/
IxStateT.map(I.Functor);
/**
 * `map` can be used to turn functions `(a: A) => B` into functions `(fa: F<A>) => F<B>` whose argument and return types
 * use the type constructor `F` to represent some computational context.
 *
 * @category Functor
 * @since 2.10.0
 */
export var flap = 
/*#__PURE__*/
flap_(Functor);
/**
 *
 * @category Apply
 * @since 2.10.0
 */
export var ap = 
/*#__PURE__*/
IxStateT.ap(I.Chain);
/**
 *
 * @category Chain
 * @since 2.10.0
 */
export var chain = 
/*#__PURE__*/
IxStateT.chain(I.Chain);
// -------------------------------------------------------------------------------------
// combinators
// -------------------------------------------------------------------------------------
/**
 * Changes the value of the local context during the execution of the action `ma` (similar to `Contravariant`'s
 * `contramap`).
 *
 * @category combinators
 * @since 2.10.0
 */
export var local = IxStateT.local();
// -------------------------------------------------------------------------------------
// do notation
// -------------------------------------------------------------------------------------
/**
 * @since 2.10.0
 */
export var ixDo = 
/*#__PURE__*/
ixDo_(Pointed);
/**
 * @since 2.10.0
 */
export var Do = ixDo;
/**
 * @since 2.10.2
 */
export var ixlet = 
/*#__PURE__*/
ixlet_(IxFunctor);
/**
 * @since 2.10.2
 */
export var let_ = ixlet;
export { 
/**
 * @since 2.10.2
 */
let_ as let, };
/**
 * @since 2.10.0
 */
export var ixbind = 
/*#__PURE__*/
ixbind_(IxChain);
/**
 * @since 2.10.0
 */
export var ixbindTo = 
/*#__PURE__*/
ixbindTo_(IxFunctor);
/**
 * @since 2.10.0
 */
export var bind = 
/*#__PURE__*/
bind_(Chain);
/**
 * @since 2.10.0
 */
export var bindTo = 
/*#__PURE__*/
bindTo_(Functor);
/**
 * ixDo-notation combinator for discarding the result of a computation rather
 * than binding it to a name. It is simply an alias for `ixchainFirst`
 * @since 2.10.0
 */
export var ixdiscard = ixchainFirst;
/**
 * Do-notation combinator for discarding the result of a computation rather
 * than binding it to a name. It is simply an alias for `chainFirst`
 * @since 2.10.0
 */
export var discard = chainFirst;
// -------------------------------------------------------------------------------------
// pipeable sequence S
// -------------------------------------------------------------------------------------
/**
 * @since 2.10.0
 */
export var ixapS = 
/*#__PURE__*/
ixapS_(IxApply);
/**
 * @since 2.10.0
 */
export var apS = 
/*#__PURE__*/
apS_(Apply);
